@@ -1,12 +1,11 @@
-__version__ = '0.7.1'
-
-from ploomber_core.telemetry.telemetry import Telemetry
+__version__ = '0.8'
 
 from .evaluator import ClassifierEvaluator
 from .nb.NotebookIntrospector import NotebookIntrospector
 from .nb.NotebookCollection import NotebookCollection
 from .nb.NotebookDatabase import NotebookDatabase
-from .SQLiteTracker import SQLiteTracker
+from .tracker import SQLiteTracker
+from .telemetry import telemetry
 
 __all__ = [
     'ClassifierEvaluator',
@@ -16,10 +15,4 @@ __all__ = [
     'NotebookDatabase',
 ]
 
-telemetry = Telemetry(
-    api_key="phc_P9SpSeypyPwxrMdFn2edOOEooQioF2axppyEeDwtMSP",
-    package_name="sklearn-evaluation",
-    version=__version__,
-)
-
 telemetry.log_api('imported')
